@@ -2,6 +2,8 @@ from itertools import chain
 from .point import *
 from .utils import *
 from .bit import *
+from .rect import *
+from .hex import *
 
 
 
